package Perinci::To::Text::I18N::id;
use parent qw(Perinci::To::Text::I18N Perinci::To::PackageBase::I18N::id);

use Locale::Maketext::Lexicon::Gettext;
our %Lexicon = %{ Locale::Maketext::Lexicon::Gettext->parse(<DATA>) };

our $VERSION = '0.18'; # VERSION

#use Data::Dump; dd \%Lexicon;

1;
# ABSTRACT: Indonesian translation for Perinci::To::Text


=pod

=head1 NAME

Perinci::To::Text::I18N::id - Indonesian translation for Perinci::To::Text

=head1 VERSION

version 0.18

=head1 FUNCTIONS

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__DATA__
msgid  ""
msgstr ""
