package Perinci::To::PackageBase::I18N;

use base 'Locale::Maketext';
use Locale::Maketext::Lexicon;

our $VERSION = '0.18'; # VERSION

1;
# ABSTRACT: Project class for Perinci::To::PackageBase

__END__
=pod

=head1 NAME

Perinci::To::PackageBase::I18N - Project class for Perinci::To::PackageBase

=head1 VERSION

version 0.18

=head1 FUNCTIONS

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

